/**
 * JASMINe
 * Copyright (C) 2009-2010 Bull S.A.S.
 * Contact: jasmine@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * $Id: JasmineEventNotificationToString.java 6819 2010-08-27 13:50:58Z danesa $
 */
package org.ow2.jasmine.monitoring.eventswitch.transformers;

import org.mule.transformers.AbstractTransformer;
import org.mule.umo.transformer.TransformerException;
import org.ow2.jasmine.event.beans.JasmineEventNotification;
import org.ow2.jasmine.event.beans.JasmineEventNotificationDetail;


/**
 * Transforms a JASMINe event notification into a string.
 */
public class JasmineEventNotificationToString extends AbstractTransformer {

    /**
     * Registers the transformer on Mule.
     *
     * @see org.mule.transformers.AbstractTransformer
     */
    public JasmineEventNotificationToString() {
        super();
        this.registerSourceType(JasmineEventNotification.class);
        this.setReturnClass(String.class);
    }


    /**
     * Transforms a JASMINe event notification into a string.
     *
     * @param src      @see org.mule.transformers.AbstractTransformer.doTransform
     * @param encoding @see org.mule.transformers.AbstractTransformer.doTransform
     *
     * @return src transformed into a string.
     */
    @Override
    protected Object doTransform(final Object src, final String encoding) throws TransformerException {

        String result = "";

        if (src instanceof JasmineEventNotification) {
            JasmineEventNotification event = (JasmineEventNotification) src;

            String formatedDate = JasmineDateFormater.getDateFormat(event.getDate());

            result += "JASMINe Event Notification object : ";

            result += "\n\tId:  " + event.getId()
            + "\n\tLevel:  " + event.getLevel()
            + "\n\tTime:   " + formatedDate
            + "\n\tMessage:  " + event.getMessage()
            + "\n\tStatus:  " + event.getStatus();

            if (!event.getDetails().isEmpty()) {
                for (JasmineEventNotificationDetail entry : event.getDetails()) {
                    result += "\n\t" + entry.getLabel() + ":  "+entry.getMessage();
                }
            }

            result += "\n\t\t";
        } else {
            throw new IllegalArgumentException("Unable to transform this source type: " + src.getClass().getName());
        }

        result +="\n";
        return result;
    }

}
